%StatorData.m
%%%%%%%%%%%%%%
%Input data for the stator used in the FEMM simulation

function [p,Qs,ActiveL,StatorRad,InnerToothTipHeight,OuterToothTipHeight, ...
          StatorBackThickness,ToothWidth,ToothOpeningWidth,ToothHeight, ...
          id,iq,Turns,WireDiam,RotorAngle,WireConductivity, ...
          muWedge,muLamination,BStatorLam,HStatorLam, ...
          SlotPitch,PolePitch,ia,ib,ic,TAmbient,hCyl, ...
          KappaAir,cthAir,KappaWedge,cthWedge, ...
          KappaStatorLam,cthStatorLam,KappaSlot, ...
          cthSlot,qSlot,EnclosureRad,KappaEnc,cthEnc,muEnc]=StatorData()

%Pole number and geometrical data of the stator%%%%%%%%%%%%%%%%%%%%%%%%%%%%
p=4;                            %Number of poles [-]
Qs=3*p*3;                       %Number of stator slots [-]
ActiveL=0.958*0.1353;           %Active machine length (stacking factor included) [m]
StatorRad=80.8e-3;              %Stator outer radius [m]
InnerToothTipHeight=1e-3;       %Inner tooth tip height (closest to slot opening) [m]
OuterToothTipHeight=2e-3;       %Outer tooth tip height [m]
StatorBackThickness=19.35e-3;   %Thickness of stator back [m]
ToothWidth=4.4e-3;              %Tooth width [m]
ToothOpeningWidth=1e-3;         %Tooth opening width [m]
ToothHeight=14.6e-3;            %Tooth height (straight part only) [m]
EnclosureRad=90e-3;            %Stator-enclosure outer radius [m]

%Compute the resulting slot and pole pitches
SlotPitch=2*pi/Qs;              %Stator slot pitch [rad]
PolePitch=2*pi/p;               %Pole pitch [rad]

%Stator winding data%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
id=0;           %d-axis current [A]
iq=5;           %q-axis current [A]
Turns=50;       %Number of turns in one slot [-]
WireDiam=1e-3;  %Wire diameter of each turn [m]
RotorAngle=0;   %Rotor angle [rad] (=0 => Rotor is magnetically aligned with the field corresponding to positive current in phase a)

%Material and thermal data%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
WireConductivity=58;            %Electrical conductivity [MS/m] (Copper=58 MS/m)
muWedge=1;                      %Relative permeability of the (linear) stator slot wedge material [-]
muLamination=10000;             %Relative permeability of the (linear) iron lamination material [-]
 
%M250-50A from www.sura.se (accessed 2013-03-04)
BStatorLam=0:0.1:1.8;
HStatorLam=[0 30.6 40.7 47.9 54.5 61.3 69.0 77.8 88.6 102 120 145 186 278 584 1600 3680 6890 11600];

%Heat transfer data due to convection to ambient
TAmbient=293.15;            %Ambient temperature [K] (0 degC => 273.15 K)
hCyl=3*6.5                   %Heat transfer coefficient due to convection to ambient [W/(m^2*K)]

%Thermal properties of the air in the air gap
KappaAir=0.026;                     %Thermal conductivity of the air in the air gap [W/(m*K)]
rhoAir=1.127;                       %Density of the air in the air gap [kg/m^3]
cthAir=(1005/rhoAir)*10^(-6);       %Specific heat capacity of the air in the air gap  [MJ/(m^3*K)]

%Thermal properties of the slot wedges
KappaWedge=0.12;                    %Thermal conductivity of the slot-wedge material [W/(m*K)]
rhoWedge=1000;                      %Density of the slow-wedge material [kg/m^3]
cthWedge=(1090/rhoWedge)*10^(-6);   %Specific heat capacity of the slot-wedge material [MJ/(m^3*K)]

%Thermal properties of the stator lamination
KappaStatorLam=28;                          %Thermal conductivity of the stator larmination [W/(m*K)]
rhoStatorLam=7650;                          %Density of the stator lamination [kg/m^3]
cthStatorLam=(486/rhoStatorLam)*10^(-6);    %Specific heat capacity of the stator lamination [MJ/(m^3*K)]

%Equivalent thermal properties of the stator slots
%KappaImp=0.68;                      %Thermal conductivity of the slot impregnation material [W/(m*K)] 
KappaImp=0.026;                     %Thermal conductivity of the slot impregnation material [W/(m*K)] 
KappaCu=166;                        %Thermal conductivity of the copper conductors [W/(m*K)]                

ACu=Turns*pi*(WireDiam/2)^2;        %Total copper area in the slot [m^2]
%Compute total slot area (minus the area of the slot wedge)
ASlot1=(0.5*(SlotPitch*(StatorRad-StatorBackThickness-ToothHeight)-ToothWidth)+ ...
    0.5*(SlotPitch*(StatorRad-StatorBackThickness)-ToothWidth))*ToothHeight;
ASlot2=(0.5*(SlotPitch*(StatorRad-StatorBackThickness-ToothHeight)-ToothWidth)+...
    0.5*ToothOpeningWidth)*(OuterToothTipHeight-InnerToothTipHeight);
ASlot=ASlot1+ASlot2;
CsFill=ACu/ASlot   %Stator-slot fill factor [-]
xiCyl=10.78*CsFill^4-10.71*CsFill^3+3.24*CsFill^2+0.018*CsFill; %Three-point parameter [-]
num=KappaImp*((CsFill-1)*xiCyl*(KappaCu-KappaImp)^2+(KappaCu+KappaImp)*(CsFill*KappaCu-CsFill*KappaImp+KappaCu+KappaImp));
den=(2*KappaCu*KappaImp-(CsFill-1)*KappaCu^2+(1+CsFill)*KappaImp^2+(CsFill-1)*((KappaCu-KappaImp)^2)*xiCyl);
KappaSlot=num/den;                %Equivalent thermal conductivity of the stator slot [W/(m*K)]

%Compute the equivalent loss density in the stator slots
RCond=(1/(WireConductivity*10^6))*ActiveL/(pi*(WireDiam/2)^2);  %Resistance of a single conductor [Ohm]
qSlot=Turns*RCond*((id^2+iq^2)/2)/(ASlot*ActiveL)  %Loss density in the stator slots [W/m^3]

JSlotPeak=Turns*sqrt(id^2+iq^2)/ASlot

rhoSlot=CsFill*8960;                    %Equivalent density of the stator slot [kg/m^3]
cthSlot=(CsFill*376/rhoSlot)*10^(-6);   %Equivalent specific heat capacity of the stator slot [MJ/(m^3*K)]

%Thermal and magnetic properties of the stator enclosure
KappaEnc=127;                        %Thermal conductivity of the stator enclosure [W/(m*K)]
%Include the effect of the interface gap between stator and stator enclosure
KappaEnc=1/((1/KappaAir)*0.037e-3/(EnclosureRad-StatorRad)+1/KappaEnc);
cthEnc=896*10^(-6);                  %Specific heat capacity of the stator enclosure [MJ/(m^3*K)];
muEnc=1;                             %Relative permeability of the (linear) stator-enclosure material [-]

%Compute the resulting phase currents
ia=id*cos(RotorAngle*p/2)-iq*sin(RotorAngle*p/2);                                    %Current in phase a [A]
ib=0.5*((-id+sqrt(3)*iq)*cos(RotorAngle*p/2)-(-sqrt(3)*id-iq)*sin(RotorAngle*p/2));  %Current in phase b [A]
ic=0.5*((-id-sqrt(3)*iq)*cos(RotorAngle*p/2)+(-sqrt(3)*id+iq)*sin(RotorAngle*p/2));  %Current in phase c [A]

ia=-ia; ib=-ib; ic=-ic; %Change sign of currents to correspond with used sign convention